# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/executor/events.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import status_pb2 as eolymp_dot_executor_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/executor/events.proto',
  package='eolymp.executor',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/executor;executor',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x65olymp/executor/events.proto\x12\x0f\x65olymp.executor\x1a\x1c\x65olymp/executor/status.proto\"=\n\x12StatusUpdatedEvent\x12\'\n\x06status\x18\x01 \x01(\x0b\x32\x17.eolymp.executor.StatusB9Z7github.com/eolymp/contracts/go/eolymp/executor;executorb\x06proto3'
  ,
  dependencies=[eolymp_dot_executor_dot_status__pb2.DESCRIPTOR,])




_STATUSUPDATEDEVENT = _descriptor.Descriptor(
  name='StatusUpdatedEvent',
  full_name='eolymp.executor.StatusUpdatedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.executor.StatusUpdatedEvent.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=140,
)

_STATUSUPDATEDEVENT.fields_by_name['status'].message_type = eolymp_dot_executor_dot_status__pb2._STATUS
DESCRIPTOR.message_types_by_name['StatusUpdatedEvent'] = _STATUSUPDATEDEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatusUpdatedEvent = _reflection.GeneratedProtocolMessageType('StatusUpdatedEvent', (_message.Message,), {
  'DESCRIPTOR' : _STATUSUPDATEDEVENT,
  '__module__' : 'eolymp.executor.events_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.executor.StatusUpdatedEvent)
  })
_sym_db.RegisterMessage(StatusUpdatedEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class ExecutorClient:
    def __init__(self, transport):
        self.transport = transport

    def DescribeLanguage(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.executor.Executor/DescribeLanguage",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.executor.DescribeLanguageOutput"),
            **kwargs,
        )

    def ListLanguages(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.executor.Executor/ListLanguages",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.executor.ListLanguagesOutput"),
            **kwargs,
        )

    def DescribeRuntime(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.executor.Executor/DescribeRuntime",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.executor.DescribeRuntimeOutput"),
            **kwargs,
        )

    def ListRuntime(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.executor.Executor/ListRuntime",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.executor.ListRuntimeOutput"),
            **kwargs,
        )

    def DescribeCodeTemplate(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.executor.Executor/DescribeCodeTemplate",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.executor.DescribeCodeTemplateOutput"),
            **kwargs,
        )




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/cognito/quota.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/cognito/quota.proto',
  package='eolymp.cognito',
  syntax='proto3',
  serialized_options=b'Z5github.com/eolymp/contracts/go/eolymp/cognito;cognito',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/cognito/quota.proto\x12\x0e\x65olymp.cognito\")\n\x05Quota\x12\r\n\x05value\x18\x01 \x01(\x05\x12\x11\n\tunlimited\x18\x02 \x01(\x08\x42\x37Z5github.com/eolymp/contracts/go/eolymp/cognito;cognitob\x06proto3'
)




_QUOTA = _descriptor.Descriptor(
  name='Quota',
  full_name='eolymp.cognito.Quota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.cognito.Quota.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unlimited', full_name='eolymp.cognito.Quota.unlimited', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=87,
)

DESCRIPTOR.message_types_by_name['Quota'] = _QUOTA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Quota = _reflection.GeneratedProtocolMessageType('Quota', (_message.Message,), {
  'DESCRIPTOR' : _QUOTA,
  '__module__' : 'eolymp.cognito.quota_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.cognito.Quota)
  })
_sym_db.RegisterMessage(Quota)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/participant.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/participant.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/judge/participant.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xf3\x04\n\x0bParticipant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ncontest_id\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\x12\r\n\x05score\x18\n \x01(\x02\x12\x0f\n\x07penalty\x18\x0b \x01(\x02\x12\x32\n\tbreakdown\x18\x0c \x03(\x0b\x32\x1f.eolymp.judge.Participant.Score\x12\x30\n\x06status\x18\x14 \x01(\x0e\x32 .eolymp.judge.Participant.Status\x12.\n\nstarted_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\nstarted_in\x18\x16 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0b\x63omplete_at\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\x0b\x63omplete_in\x18\x1a \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x10\n\x08passcode\x18\x1e \x01(\t\x1ap\n\x05Score\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12\x0f\n\x07penalty\x18\x03 \x01(\x02\x12\x0e\n\x06solved\x18\x04 \x01(\x08\x12\x12\n\npercentage\x18\x05 \x01(\x02\x12\x0f\n\x07submits\x18\x06 \x01(\r\"W\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05READY\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\x12\x0c\n\x08INACTIVE\x10\x04\x12\x10\n\x0cUNREGISTERED\x10\x05\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])



_PARTICIPANT_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Participant.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INACTIVE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNREGISTERED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=654,
  serialized_end=741,
)
_sym_db.RegisterEnumDescriptor(_PARTICIPANT_STATUS)


_PARTICIPANT_SCORE = _descriptor.Descriptor(
  name='Score',
  full_name='eolymp.judge.Participant.Score',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.judge.Participant.Score.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Participant.Score.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.judge.Participant.Score.penalty', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solved', full_name='eolymp.judge.Participant.Score.solved', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='eolymp.judge.Participant.Score.percentage', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submits', full_name='eolymp.judge.Participant.Score.submits', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=652,
)

_PARTICIPANT = _descriptor.Descriptor(
  name='Participant',
  full_name='eolymp.judge.Participant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Participant.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.judge.Participant.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contest_id', full_name='eolymp.judge.Participant.contest_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='eolymp.judge.Participant.username', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='eolymp.judge.Participant.score', index=4,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='penalty', full_name='eolymp.judge.Participant.penalty', index=5,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='breakdown', full_name='eolymp.judge.Participant.breakdown', index=6,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Participant.status', index=7,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='eolymp.judge.Participant.started_at', index=8,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started_in', full_name='eolymp.judge.Participant.started_in', index=9,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='complete_at', full_name='eolymp.judge.Participant.complete_at', index=10,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='complete_in', full_name='eolymp.judge.Participant.complete_in', index=11,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='passcode', full_name='eolymp.judge.Participant.passcode', index=12,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PARTICIPANT_SCORE, ],
  enum_types=[
    _PARTICIPANT_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=741,
)

_PARTICIPANT_SCORE.containing_type = _PARTICIPANT
_PARTICIPANT.fields_by_name['breakdown'].message_type = _PARTICIPANT_SCORE
_PARTICIPANT.fields_by_name['status'].enum_type = _PARTICIPANT_STATUS
_PARTICIPANT.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARTICIPANT.fields_by_name['started_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PARTICIPANT.fields_by_name['complete_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PARTICIPANT.fields_by_name['complete_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PARTICIPANT_STATUS.containing_type = _PARTICIPANT
DESCRIPTOR.message_types_by_name['Participant'] = _PARTICIPANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Participant = _reflection.GeneratedProtocolMessageType('Participant', (_message.Message,), {

  'Score' : _reflection.GeneratedProtocolMessageType('Score', (_message.Message,), {
    'DESCRIPTOR' : _PARTICIPANT_SCORE,
    '__module__' : 'eolymp.judge.participant_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Participant.Score)
    })
  ,
  'DESCRIPTOR' : _PARTICIPANT,
  '__module__' : 'eolymp.judge.participant_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Participant)
  })
_sym_db.RegisterMessage(Participant)
_sym_db.RegisterMessage(Participant.Score)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/form.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/form.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x65olymp/judge/form.proto\x12\x0c\x65olymp.judge\"\xd0\x03\n\x04\x46orm\x12(\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x18.eolymp.judge.Form.Field\x1a\x9d\x03\n\x05\x46ield\x12\n\n\x02id\x18\x01 \x01(\t\x12\x39\n\x0b\x64\x65scription\x18\n \x03(\x0b\x32$.eolymp.judge.Form.Field.Description\x12+\n\x04type\x18\x14 \x01(\x0e\x32\x1d.eolymp.judge.Form.Field.Type\x12\x10\n\x08required\x18\x1e \x01(\x08\x12\x0e\n\x06regexp\x18\x1f \x01(\t\x12\x0b\n\x03min\x18  \x01(\x05\x12\x0b\n\x03max\x18! \x01(\x05\x12\x0f\n\x07\x63hoices\x18\" \x03(\t\x1a\\\n\x0b\x44\x65scription\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\x08\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x0c\n\x04help\x18\x04 \x01(\t\x12\x0f\n\x07\x63hoices\x18\x05 \x03(\t\"u\n\x04Type\x12\n\n\x06STRING\x10\x00\x12\x08\n\x04TEXT\x10\x01\x12\n\n\x06NUMBER\x10\x02\x12\n\n\x06\x43HOICE\x10\x03\x12\x08\n\x04\x44\x41TE\x10\x04\x12\t\n\x05\x45MAIL\x10\x05\x12\x0c\n\x08\x43HECKBOX\x10\x06\x12\x1c\n\x17UKRAINE_CITY_AND_REGION\x10\xe8\x07\"f\n\x0cRegistration\x12-\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x1f.eolymp.judge.Registration.Data\x1a\'\n\x04\x44\x61ta\x12\x10\n\x08\x66ield_id\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\tB3Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
)



_FORM_FIELD_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.judge.Form.Field.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STRING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUMBER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHOICE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMAIL', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHECKBOX', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UKRAINE_CITY_AND_REGION', index=7, number=1000,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=389,
  serialized_end=506,
)
_sym_db.RegisterEnumDescriptor(_FORM_FIELD_TYPE)


_FORM_FIELD_DESCRIPTION = _descriptor.Descriptor(
  name='Description',
  full_name='eolymp.judge.Form.Field.Description',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default', full_name='eolymp.judge.Form.Field.Description.default', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='eolymp.judge.Form.Field.Description.locale', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='eolymp.judge.Form.Field.Description.label', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='help', full_name='eolymp.judge.Form.Field.Description.help', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choices', full_name='eolymp.judge.Form.Field.Description.choices', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=387,
)

_FORM_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='eolymp.judge.Form.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Form.Field.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='eolymp.judge.Form.Field.description', index=1,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.judge.Form.Field.type', index=2,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='eolymp.judge.Form.Field.required', index=3,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regexp', full_name='eolymp.judge.Form.Field.regexp', index=4,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='eolymp.judge.Form.Field.min', index=5,
      number=32, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='eolymp.judge.Form.Field.max', index=6,
      number=33, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='choices', full_name='eolymp.judge.Form.Field.choices', index=7,
      number=34, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FORM_FIELD_DESCRIPTION, ],
  enum_types=[
    _FORM_FIELD_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=506,
)

_FORM = _descriptor.Descriptor(
  name='Form',
  full_name='eolymp.judge.Form',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='eolymp.judge.Form.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FORM_FIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=506,
)


_REGISTRATION_DATA = _descriptor.Descriptor(
  name='Data',
  full_name='eolymp.judge.Registration.Data',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_id', full_name='eolymp.judge.Registration.Data.field_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='eolymp.judge.Registration.Data.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=571,
  serialized_end=610,
)

_REGISTRATION = _descriptor.Descriptor(
  name='Registration',
  full_name='eolymp.judge.Registration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='eolymp.judge.Registration.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REGISTRATION_DATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=610,
)

_FORM_FIELD_DESCRIPTION.containing_type = _FORM_FIELD
_FORM_FIELD.fields_by_name['description'].message_type = _FORM_FIELD_DESCRIPTION
_FORM_FIELD.fields_by_name['type'].enum_type = _FORM_FIELD_TYPE
_FORM_FIELD.containing_type = _FORM
_FORM_FIELD_TYPE.containing_type = _FORM_FIELD
_FORM.fields_by_name['fields'].message_type = _FORM_FIELD
_REGISTRATION_DATA.containing_type = _REGISTRATION
_REGISTRATION.fields_by_name['data'].message_type = _REGISTRATION_DATA
DESCRIPTOR.message_types_by_name['Form'] = _FORM
DESCRIPTOR.message_types_by_name['Registration'] = _REGISTRATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Form = _reflection.GeneratedProtocolMessageType('Form', (_message.Message,), {

  'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {

    'Description' : _reflection.GeneratedProtocolMessageType('Description', (_message.Message,), {
      'DESCRIPTOR' : _FORM_FIELD_DESCRIPTION,
      '__module__' : 'eolymp.judge.form_pb2'
      # @@protoc_insertion_point(class_scope:eolymp.judge.Form.Field.Description)
      })
    ,
    'DESCRIPTOR' : _FORM_FIELD,
    '__module__' : 'eolymp.judge.form_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Form.Field)
    })
  ,
  'DESCRIPTOR' : _FORM,
  '__module__' : 'eolymp.judge.form_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Form)
  })
_sym_db.RegisterMessage(Form)
_sym_db.RegisterMessage(Form.Field)
_sym_db.RegisterMessage(Form.Field.Description)

Registration = _reflection.GeneratedProtocolMessageType('Registration', (_message.Message,), {

  'Data' : _reflection.GeneratedProtocolMessageType('Data', (_message.Message,), {
    'DESCRIPTOR' : _REGISTRATION_DATA,
    '__module__' : 'eolymp.judge.form_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.judge.Registration.Data)
    })
  ,
  'DESCRIPTOR' : _REGISTRATION,
  '__module__' : 'eolymp.judge.form_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Registration)
  })
_sym_db.RegisterMessage(Registration)
_sym_db.RegisterMessage(Registration.Data)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class AtlasClient:
    def __init__(self, transport):
        self.transport = transport

    def CreateProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/CreateProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.CreateProblemOutput"),
            **kwargs,
        )

    def DeleteProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DeleteProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DeleteProblemOutput"),
            **kwargs,
        )

    def ListProblems(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/ListProblems",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.ListProblemsOutput"),
            **kwargs,
        )

    def DescribeProblem(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DescribeProblem",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DescribeProblemOutput"),
            **kwargs,
        )

    def ListExamples(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/ListExamples",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.ListExamplesOutput"),
            **kwargs,
        )

    def UpdateVerifier(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateVerifier",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateVerifierOutput"),
            **kwargs,
        )

    def DescribeVerifier(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DescribeVerifier",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DescribeVerifierOutput"),
            **kwargs,
        )

    def UpdateInteractor(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateInteractor",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateInteractorOutput"),
            **kwargs,
        )

    def DescribeInteractor(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DescribeInteractor",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DescribeInteractorOutput"),
            **kwargs,
        )

    def CreateStatement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/CreateStatement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.CreateStatementOutput"),
            **kwargs,
        )

    def UpdateStatement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateStatement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateStatementOutput"),
            **kwargs,
        )

    def DeleteStatement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DeleteStatement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DeleteStatementOutput"),
            **kwargs,
        )

    def ListStatements(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/ListStatements",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.ListStatementsOutput"),
            **kwargs,
        )

    def DescribeStatement(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DescribeStatement",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DescribeStatementOutput"),
            **kwargs,
        )

    def CreateTestset(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/CreateTestset",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.CreateTestsetOutput"),
            **kwargs,
        )

    def UpdateTestset(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateTestset",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateTestsetOutput"),
            **kwargs,
        )

    def DeleteTestset(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DeleteTestset",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DeleteTestsetOutput"),
            **kwargs,
        )

    def ListTestsets(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/ListTestsets",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.ListTestsetsOutput"),
            **kwargs,
        )

    def DescribeTestset(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DescribeTestset",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DescribeTestsetOutput"),
            **kwargs,
        )

    def CreateTest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/CreateTest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.CreateTestOutput"),
            **kwargs,
        )

    def UpdateTest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateTest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateTestOutput"),
            **kwargs,
        )

    def DeleteTest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DeleteTest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DeleteTestOutput"),
            **kwargs,
        )

    def ListTests(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/ListTests",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.ListTestsOutput"),
            **kwargs,
        )

    def DescribeTest(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DescribeTest",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DescribeTestOutput"),
            **kwargs,
        )

    def GrantPermission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/GrantPermission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.GrantPermissionOutput"),
            **kwargs,
        )

    def RevokePermission(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/RevokePermission",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.RevokePermissionOutput"),
            **kwargs,
        )

    def ListPermissions(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/ListPermissions",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.ListPermissionsOutput"),
            **kwargs,
        )

    def CreateCodeTemplate(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/CreateCodeTemplate",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.CreateCodeTemplateOutput"),
            **kwargs,
        )

    def UpdateCodeTemplate(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/UpdateCodeTemplate",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.UpdateCodeTemplateOutput"),
            **kwargs,
        )

    def DeleteCodeTemplate(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DeleteCodeTemplate",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DeleteCodeTemplateOutput"),
            **kwargs,
        )

    def ListCodeTemplates(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/ListCodeTemplates",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.ListCodeTemplatesOutput"),
            **kwargs,
        )

    def DescribeCodeTemplate(self, request, **kwargs):
        return self.transport.request(
            url="eolymp.atlas.Atlas/DescribeCodeTemplate",
            request=request,
            response_obj=_sym_db.GetSymbol("eolymp.atlas.DescribeCodeTemplateOutput"),
            **kwargs,
        )

